Function to get all processes which are enabled and write output files:

getEnabledAndFileOutputProcessNames(projectPath)

Arguments

projectPath

The path to the StoX project, i.e., the folder of the project with the sub folders "input", "output" and "process". Can possibly be the path to a file inside the project folder.

Value

A list with one vector of process names per model.