This function gets the paths defined by initiateRstoxFramework.

getProjectPaths(projectPath, name = NULL)

Arguments

projectPath

The path to the StoX project, i.e., the folder of the project with the sub folders "input", "output" and "process". Can possibly be the path to a file inside the project folder.

name

A string naming the path element to get. Set this to NULL to get all paths.

Value

A list of file paths prefixed by the input projectPath and suffixed by the elements listed below (use name to output only one or more elements). E.g., projectPath = "blah" and name = "inputFolders" returns the vector c("blah/input/acoustic", "blah/input/biotic", "blah/input/landing"). If the input projectPath points to a zipped StoX project, connections to files inside the zip are returned:

acoustic

input/acoustic

biotic

input/biotic

landing

input/landing

baseline

output/baseline

analysis

output/analysis

report

output/report

process

process

inputFolders

Vector:

  • input/acoustic

  • input/biotic

  • input/landing

outputFolders

Vector:

  • baseline: output/baseline

  • analysis: output/analysis

  • report: output/report

input

input

output

output

process

process

stoxFolders

Vector:

  • input: input

  • output: output

  • process: process

stoxFolderStructure

Vector:

  • acoustic: input/acoustic

  • biotic: input/biotic

  • landing: input/landing

  • baseline: output/baseline

  • analysis: output/analysis

  • report: output/report

  • process: process

projectSessionFolder

process/projectSession

dataFolder

process/projectSession/data

memoryFolder

process/projectSession/memory

statusFolder

process/projectSession/status

progressFile

List:

  • $baseline: process/projectSession/status/baselineProgress.txt

  • $analysis: process/projectSession/status/analysisProgress.txt

  • $report: process/projectSession/status/analysisProgress.txt

NFile

List:

  • $baseline: process/projectSession/status/baselineN.txt

  • $analysis: process/projectSession/status/analysisN.txt

  • $report: process/projectSession/status/reportN.txt

stopFile

List:

  • $baseline: process/projectSession/status/baselineStop.txt

  • $analysis: process/projectSession/status/analysisStop.txt

  • $report: process/projectSession/status/reportStop.txt

dataModelsFolder

process/projectSession/data/models

dataModelsFolders

Vector:

  • baseline: process/projectSession/data/models/baseline

  • analysis: process/projectSession/data/models/analysis

  • report: process/projectSession/data/models/report

memoryCurrentFolder

process/projectSession/memory/current

memoryHistoryFolder

process/projectSession/memory/history

memoryModelsFolder

process/projectSession/memory/models

memoryModelsFolders

Vector:

  • baseline: process/projectSession/memory/models/baseline

  • analysis: process/projectSession/memory/models/analysis

  • report: process/projectSession/memory/models/report

memoryCurrentModelsFolder

process/projectSession/memory/current/models

memoryCurrentModelsFolders

Vector:

  • baseline: process/projectSession/memory/current/models/baseline

  • analysis: process/projectSession/memory/current/models/analysis

  • report: process/projectSession/memory/current/models/report

projectSessionFolderStructure

Vector:

  • process/projectSession/data

  • process/projectSession/memory

  • process/projectSession/status

  • process/projectSession/data/models

  • process/projectSession/data/models/baseline

  • process/projectSession/data/models/analysis

  • process/projectSession/data/models/report

  • process/projectSession/memory/current

  • process/projectSession/memory/history

  • process/projectSession/memory/models

  • process/projectSession/memory/models/baseline

  • process/projectSession/memory/models/analysis

  • process/projectSession/memory/models/report

  • process/projectSession/memory/current/models

  • process/projectSession/memory/current/models/baseline

  • process/projectSession/memory/current/models/analysis

  • process/projectSession/memory/current/models/report

projectXMLFile

process/project.xml

projectJSONFile

process/project.json

projectSavedStatusFile

process/projectSession/status/projectSavedStatus.txt

modelIsRunningFile

List:

  • $baseline: process/projectSession/status/baselineIsRunning.txt

  • $analysis: process/projectSession/status/analysisIsRunning.txt

  • $report: process/projectSession/status/reportIsRunning.txt

projectMemoryIndexFile

process/projectSession/memory/history/projectMemoryIndex.txt

processIndexTableFile

process/projectSession/memory/current/processIndexTable.txt

activeProcessIDFile

process/project.xml

maxProcessIntegerIDFile

process/projectSession/memory/current/maxProcessIntegerID.txt

projectDescriptionAttributesFile

process/projectSession/memory/models/projectDescriptionAttributes.rds

Examples

getProjectPaths("blah", "inputFolders")
#> [1] "blah/input/acoustic" "blah/input/biotic"   "blah/input/landing"