This function is useful to make a copy of a potentially zipped project.

unzipAndCopyProject(projectPath, newProjectPath, copydir = tempdir(), ...)

Arguments

projectPath

The path to the StoX project, i.e., the folder of the project with the sub folders "input", "output" and "process". Can possibly be the path to a file inside the project folder.

newProjectPath

The path to the copied StoX project.

copydir

The directory in which to place the copy, defaulted to the tempdir.

...

Passed to copyProject.

Value

The path to the copy of the StoX project.