Zip a StoX project

zipProject(projectPath, zipPath = NULL, zipDir = NULL, ow = FALSE)

Arguments

projectPath

The path to the StoX project, i.e., the folder of the project with the sub folders "input", "output" and "process". Can possibly be the path to a file inside the project folder.

zipPath

The file path of the ziped StoX project.

zipDir

The file path of the directory in which to place the ziped StoX project.

ow

Logical: If TRUE overwrite the zip if already present.