initiateRstoxFramework.R/Framework.R
getProjectPaths.RdThis function gets the paths defined by initiateRstoxFramework.
getProjectPaths(projectPath, name = NULL)A list of file paths prefixed by the input projectPath and suffixed by the elements listed below (use name to output only one or more elements). E.g., projectPath = "blah" and name = "inputFolders" returns the vector c("blah/input/acoustic", "blah/input/biotic", "blah/input/landing"). If the input projectPath points to a zipped StoX project, connections to files inside the zip are returned:
input/acoustic
input/biotic
input/landing
output/baseline
output/analysis
output/report
process
Vector:
input/acoustic
input/biotic
input/landing
Vector:
baseline: output/baseline
analysis: output/analysis
report: output/report
input
output
process
Vector:
input: input
output: output
process: process
Vector:
acoustic: input/acoustic
biotic: input/biotic
landing: input/landing
baseline: output/baseline
analysis: output/analysis
report: output/report
process: process
process/projectSession
process/projectSession/data
process/projectSession/memory
process/projectSession/status
List:
$baseline: process/projectSession/status/baselineProgress.txt
$analysis: process/projectSession/status/analysisProgress.txt
$report: process/projectSession/status/analysisProgress.txt
List:
$baseline: process/projectSession/status/baselineN.txt
$analysis: process/projectSession/status/analysisN.txt
$report: process/projectSession/status/reportN.txt
List:
$baseline: process/projectSession/status/baselineStop.txt
$analysis: process/projectSession/status/analysisStop.txt
$report: process/projectSession/status/reportStop.txt
process/projectSession/data/models
Vector:
baseline: process/projectSession/data/models/baseline
analysis: process/projectSession/data/models/analysis
report: process/projectSession/data/models/report
process/projectSession/memory/current
process/projectSession/memory/history
process/projectSession/memory/models
Vector:
baseline: process/projectSession/memory/models/baseline
analysis: process/projectSession/memory/models/analysis
report: process/projectSession/memory/models/report
process/projectSession/memory/current/models
Vector:
baseline: process/projectSession/memory/current/models/baseline
analysis: process/projectSession/memory/current/models/analysis
report: process/projectSession/memory/current/models/report
Vector:
process/projectSession/data
process/projectSession/memory
process/projectSession/status
process/projectSession/data/models
process/projectSession/data/models/baseline
process/projectSession/data/models/analysis
process/projectSession/data/models/report
process/projectSession/memory/current
process/projectSession/memory/history
process/projectSession/memory/models
process/projectSession/memory/models/baseline
process/projectSession/memory/models/analysis
process/projectSession/memory/models/report
process/projectSession/memory/current/models
process/projectSession/memory/current/models/baseline
process/projectSession/memory/current/models/analysis
process/projectSession/memory/current/models/report
process/project.xml
process/project.json
process/projectSession/status/projectSavedStatus.txt
List:
$baseline: process/projectSession/status/baselineIsRunning.txt
$analysis: process/projectSession/status/analysisIsRunning.txt
$report: process/projectSession/status/reportIsRunning.txt
process/projectSession/memory/history/projectMemoryIndex.txt
process/projectSession/memory/current/processIndexTable.txt
process/project.xml
process/projectSession/memory/current/maxProcessIntegerID.txt
process/projectSession/memory/models/projectDescriptionAttributes.rds
getProjectPaths("blah", "inputFolders")
#> [1] "blah/input/acoustic" "blah/input/biotic" "blah/input/landing"