This function is useful to make a copy of a potentially zipped project.
unzipAndCopyProject(projectPath, newProjectPath, copydir = tempdir(), ...)The path to the StoX project, i.e., the folder of the project with the sub folders "input", "output" and "process". Can possibly be the path to a file inside the project folder.
The path to the copied StoX project.
The directory in which to place the copy, defaulted to the tempdir.
Passed to copyProject.
The path to the copy of the StoX project.