Zip a StoX project
zipProject(projectPath, zipPath = NULL, zipDir = NULL, ow = FALSE)The path to the StoX project, i.e., the folder of the project with the sub folders "input", "output" and "process". Can possibly be the path to a file inside the project folder.
The file path of the ziped StoX project.
The file path of the directory in which to place the ziped StoX project.
Logical: If TRUE overwrite the zip if already present.